@@ -786,6 +786,7 @@ void ActionManager::initActions()
 
 void ActionManager::updateHamburgerMenu()
 {
+    delete mHamburgerMenu->menu();
     auto menu = new QMenu;
 
     menu->addAction(mACollection->action(QStringLiteral("conf_datetime")));
@@ -1075,7 +1076,7 @@ void ActionManager::configureDateTime()
     QProcess proc;
     const QString program = QStringLiteral("kcmshell6");
     QStringList arguments;
-    arguments << QStringLiteral("formats") << QStringLiteral("translations") << QStringLiteral("clock");
+    arguments << QStringLiteral("kcm_regionandlang") << QStringLiteral("clock");
 
     if (!proc.startDetached(program, arguments)) {
         KMessageBox::error(dialogParent(), i18n("Could not start control module for date and time format."));
